uim.codec.writer API documentation
Description: Writer This package contains different encoders for ink formats: …

# Module `uim.codec.writer`

# Writer

This package contains different encoders for ink formats:

- Universal Ink Model (v3.1.0)

Expand source code

    # -*- coding: utf-8 -*-
    """
    Writer
    =======
    This package contains different encoders for ink formats:

    - Universal Ink Model (v3.1.0)
    """
    __all__ = ['encoder']

    from uim.codec.writer import encoder

## Sub-modules

`uim.codec.writer.encoder`

  Encoder classes

  This package contains all encoders for the Universal Ink Model: …